@@ -121,6 +121,12 @@ class SetLoadBalancerTCPListenerAttributeRequest(RpcRequest):
 	def set_HealthCheckInterval(self,HealthCheckInterval):
 		self.add_query_param('HealthCheckInterval',HealthCheckInterval)
 
+	def get_ConnectionDrain(self):
+		return self.get_query_params().get('ConnectionDrain')
+
+	def set_ConnectionDrain(self,ConnectionDrain):
+		self.add_query_param('ConnectionDrain',ConnectionDrain)
+
 	def get_HealthCheckConnectTimeout(self):
 		return self.get_query_params().get('HealthCheckConnectTimeout')
 
@@ -181,6 +187,12 @@ class SetLoadBalancerTCPListenerAttributeRequest(RpcRequest):
 	def set_OwnerAccount(self,OwnerAccount):
 		self.add_query_param('OwnerAccount',OwnerAccount)
 
+	def get_ConnectionDrainTimeout(self):
+		return self.get_query_params().get('ConnectionDrainTimeout')
+
+	def set_ConnectionDrainTimeout(self,ConnectionDrainTimeout):
+		self.add_query_param('ConnectionDrainTimeout',ConnectionDrainTimeout)
+
 	def get_HealthCheckConnectPort(self):
 		return self.get_query_params().get('HealthCheckConnectPort')
 
